@@ -1,12 +1,12 @@
 ######################################################################
-# authadmin_cookie.inc.cgi - This is PyukiWiki, yet another Wiki clone.
-# $Id: authadmin_cookie.inc.pl,v 1.50 2006/03/17 14:18:01 papu Exp $
+# authadmin_cookie.inc.pl - This is PyukiWiki, yet another Wiki clone.
+# $Id: authadmin_cookie.inc.pl,v 1.78 2010/12/14 22:20:00 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.8 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2010 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2010 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -20,7 +20,7 @@
 # To use this plugin, rename to 'authadmin_cookie.inc.cgi'
 ######################################################################
 #
-# ѥɤΰcookie¸ɾǡ
+# ѥɤΰcookie¸
 #
 # ¸ʤcookieȤơ֥饦Υåͭʴ֤
 # ѥɤ¸ޤС֥饦Ĥޤ
@@ -164,7 +164,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/ExPlugin/authadmin_cookie/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/lib/authadmin_cookie.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/lib/authadmin_cookie.inc.pl?view=log>
 
 =back
 
@@ -174,17 +174,19 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/lib/au
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
 L<http://pyukiwiki.sourceforge.jp/>
 
+=back
+
 =head1 LICENSE
 
-Copyright (C) 2005-2006 by Nanami.
+Copyright (C) 2005-2010 by Nanami.
 
-Copyright (C) 2005-2006 by PyukiWiki Developers Team
+Copyright (C) 2005-2010 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
