@@ -1,12 +1,12 @@
 ######################################################################
 # bugtrack.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: bugtrack.inc.pl,v 1.59 2007/07/15 07:40:09 papu Exp $
+# $Id: bugtrack.inc.pl,v 1.89 2011/04/13 08:42:38 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" version 0.1.8-p5 $$
 # Author: Nekyo
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -14,11 +14,7 @@
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
-# Return Code:LF Japanese Code=EUC 1TAB=4Spaces
-#
-# Base on PukiWiki BugTrack Plugin
-# CopyRight 2002 Y.MASUI GPL2
-# http://masui.net/pukiwiki/ <masui (at) masui (dot) net>
+# Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
 # ѹ:
 #  2002.06.17: Ϥ
@@ -354,7 +350,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/bugtrack/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/bugtrack.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/bugtrack.inc.pl?view=log>
 
 =back
 
@@ -362,9 +358,13 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =over 4
 
+=head1 AUTHOR
+
+=over 4
+
 =item Nekyo
 
-L<http://nekyo.hp.infoseek.co.jp/>
+L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
@@ -374,9 +374,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2004-2007 by Nekyo.
+Copyright (C) 2004-2011 by Nekyo.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
