@@ -1,12 +1,12 @@
 ######################################################################
 # counter_viewer.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: counter_viewer.inc.pl,v 1.8 2006/03/17 14:00:10 papu Exp $
+# $Id: counter_viewer.inc.pl,v 1.37 2010/12/14 22:20:00 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.8 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2010 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2010 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -96,9 +96,20 @@ sub plugin_counter_viewer_index {
 	my %auth=@_;
 	my @list=();
 	my $body;
-	foreach my $pages (keys %::database) {
-		my %counter=&plugin_counter_do($pages,"r");
-		push(@list,"$pages\t$counter{total}\t$counter{today}\t$counter{yesterday}\t$counter{version}");
+#	foreach my $pages (keys %::database) {
+#		my %counter=&plugin_counter_do($pages,"r");
+#		push(@list,"$pages\t$counter{total}\t$counter{today}\t$counter{yesterday}\t$counter{version}");
+#	}
+
+	# changes other counters
+	opendir(DIR,$::counter_dir);
+	my $file;
+	while($file=readdir(DIR)) {
+		next if($file!~/\.count$/);
+		$file=~s/\.count$//g;
+		my $page=&decode($file);
+		my %counter=&plugin_counter_do($page,"r");
+		push(@list,"$page\t$counter{total}\t$counter{today}\t$counter{yesterday}\t$counter{version}");
 	}
 
 	@list=sort { (split(/\t/,$a))[0] cmp (split(/\t/,$b))[0] } @list;
@@ -188,7 +199,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Admin/counter_viewer/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/counter_viewer.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/counter_viewer.inc.pl?view=log>
 
 
 =back
@@ -199,7 +210,7 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
@@ -209,9 +220,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2006 by Nanami.
+Copyright (C) 2005-2010 by Nanami.
 
-Copyright (C) 2005-2006 by PyukiWiki Developers Team
+Copyright (C) 2005-2010 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
