@@ -1,12 +1,12 @@
 ######################################################################
 # help.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: help.inc.pl,v 1.8 2006/03/17 14:00:10 papu Exp $
+# $Id: help.inc.pl,v 1.40 2011/01/25 03:11:15 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.8-p2 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -82,7 +82,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/help/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/help.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/help.inc.pl?view=log>
 
 =back
 
@@ -92,7 +92,7 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
@@ -102,9 +102,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2006 by Nanami.
+Copyright (C) 2005-2011 by Nanami.
 
-Copyright (C) 2005-2006 by PyukiWiki Developers Team
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
