@@ -1,12 +1,12 @@
 ######################################################################
 # link.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: link.pl,v 1.59 2007/07/15 07:40:09 papu Exp $
+# $Id: link.pl,v 1.79 2010/12/14 22:20:00 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" version 0.1.8 $$
 # Author: Hiroshi Yuki http://www.hyuki.com/
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# Copyright (C) 2004-2010 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2010 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -87,7 +87,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/link/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/link.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/link.pl?view=log>
 
 =back
 
@@ -95,7 +95,9 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =over 4
 
+=item Hiroshi Yuki
 
+L<http://www.hyuki.com/>
 
 =item PyukiWiki Developers Team
 
@@ -105,9 +107,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2002-2007 by Hiroshi Yuki.
+Copyright (C) 2002-2010 by Hiroshi Yuki.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2010 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
