@@ -1,12 +1,12 @@
 ######################################################################
 # nofollow.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: nofollow.inc.pl,v 1.56 2007/07/15 07:40:09 papu Exp $
+# $Id: nofollow.inc.pl,v 1.85 2011/04/13 08:42:38 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
-# Author: Nekyo
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.8-p5 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -48,7 +48,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/nofollow/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/nofollow.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/nofollow.inc.pl?view=log>
 
 =back
 
@@ -56,9 +56,9 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =over 4
 
-=item Nekyo
+=item Nanami
 
-L<http://nekyo.hp.infoseek.co.jp/>
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
@@ -68,9 +68,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2004-2007 by Nekyo.
+Copyright (C) 2005-2011 by Nanami.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
