@@ -1,12 +1,12 @@
 ######################################################################
 # pcomment.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: pcomment.inc.pl,v 1.4 2006/03/17 14:00:10 papu Exp $
+# $Id: pcomment.inc.pl,v 1.37 2011/02/22 20:59:12 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.8-p3 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -79,6 +79,8 @@ $pcomment::frozencommentpage=1
 	if(!defined($pcomment::frozencommentpage));
 
 sub plugin_pcomment_action {
+	&::spam_filter($::form{mymsg}, 2);
+	&::spam_filter($::form{myname}, 0);
 
 	if (($::form{mymsg} =~ /^\s*$/ && $pcomment::nodata eq 1)
 	 || ($::form{myname} =~ /^\s*$/ && $pcomment::noname eq 1)
@@ -441,7 +443,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/pcomment/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/pcomment.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/pcomment.inc.pl?view=log>
 
 =back
 
@@ -451,7 +453,7 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =item Nanami
 
-L<http://lineage.netgamers.jp/> etc...
+L<http://nanakochi.daiba.cx/> etc...
 
 =item PyukiWiki Developers Team
 
@@ -461,9 +463,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2005-2006 by Nanami.
+Copyright (C) 2005-2011 by Nanami.
 
-Copyright (C) 2005-2006 by PyukiWiki Developers Team
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
