@@ -1,12 +1,12 @@
 ######################################################################
 # recent.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: recent.inc.pl,v 1.59 2007/07/15 07:40:09 papu Exp $
+# $Id: recent.inc.pl,v 1.89 2011/04/13 08:42:38 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" version 0.1.8-p5 $$
 # Author: Nekyo
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -16,6 +16,7 @@
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
+# v 0.1.9 #recent(count,ɽʤڡɽ) ɲ
 # v 0.1.6 ȾѥڡΥڡбTime::Local
 #         actionˤб
 # v 0.0.3 : + ڡ̾ϰɽʤ
@@ -75,7 +76,9 @@ sub plugin_recent_action {
 }
 
 sub plugin_recent_convert {
-	my $limit = shift;
+	# change v 0.1.9
+	my $argv = shift;
+	my ($limit, $ignore) = split(/,/, $argv);
 	if ($limit eq '') { $limit = 10; }
 	my $recentchanges = $::database{$::RecentChanges};
 	my $count = 0;
@@ -86,6 +89,11 @@ sub plugin_recent_convert {
 		# v0.1.6
 		/^\- (\d\d\d\d\-\d\d\-\d\d) \(...\) \d\d:\d\d:\d\d (.*?)\ \ \-/;	# date format.
 		next if ($2 =~ /\[*:/ || $2 =~ /$::non_list/ || !&is_readable($2));
+		# add v 0.1.9
+		if ($ignore ne '') {
+			next if $2 =~ /($ignore)/;
+		}
+
 		if ($2) {
 			if ($date ne $1) {
 				if ($date ne '') { $out .= "</ul>\n"; }
@@ -108,7 +116,7 @@ recent.inc.pl - PyukiWiki Plugin
 
 =head1 SYNOPSIS
 
- #recent(count)
+ #recent(count[,regex of ignore pages)
 
 =head1 DESCRIPTION
 
@@ -126,7 +134,7 @@ L<http://pyukiwiki.sourceforge.jp/PyukiWiki/Plugin/Standard/recent/>
 
 =item PyukiWiki CVS
 
-L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin/recent.inc.pl>
+L<http://sourceforge.jp/cvs/view/pyukiwiki/PyukiWiki-Devel/plugin/recent.inc.pl?view=log>
 
 =back
 
@@ -136,7 +144,7 @@ L<http://cvs.sourceforge.jp/cgi-bin/viewcvs.cgi/pyukiwiki/PyukiWiki-Devel/plugin
 
 =item Nekyo
 
-L<http://nekyo.hp.infoseek.co.jp/>
+L<http://nekyo.qp.land.to/>
 
 =item PyukiWiki Developers Team
 
@@ -146,9 +154,9 @@ L<http://pyukiwiki.sourceforge.jp/>
 
 =head1 LICENSE
 
-Copyright (C) 2004-2007 by Nekyo.
+Copyright (C) 2004-2011 by Nekyo.
 
-Copyright (C) 2005-2007 by PyukiWiki Developers Team
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
 
 License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
 
