@@ -1,12 +1,12 @@
 ######################################################################
 # source.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: source.inc.pl,v 1.4 2007/07/15 07:40:09 papu Exp $
+# $Id: source.inc.pl,v 1.28 2011/01/25 03:11:15 papu Exp $
 #
-# "PyukiWiki" version 0.1.7 $$
+# "PyukiWiki" version 0.1.8-p2 $$
 # Author: Nekyo
-# Copyright (C) 2004-2007 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2007 PyukiWiki Developers Team
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -16,7 +16,6 @@
 # modify it under the same terms as Perl itself.
 # Return:LF Code=EUC-JP 1TAB=4Spaces
 ######################################################################
-######################################################################
 # Usage:?cmd=source&page=pagename
 ######################################################################
 
@@ -32,3 +31,33 @@ sub plugin_source_action {
 1;
 __END__
 
+=head1 NAME
+
+source.inc.pl - PyukiWiki Plugin
+
+=head1 AUTHOR
+
+=over 4
+
+=item Nekyo
+
+L<http://nekyo.qp.land.to/>
+
+=item PyukiWiki Developers Team
+
+L<http://pyukiwiki.sourceforge.jp/>
+
+=back
+
+=head1 LICENSE
+
+Copyright (C) 2004-2011 by Nekyo.
+
+Copyright (C) 2005-2011 by PyukiWiki Developers Team
+
+License is GNU GENERAL PUBLIC LICENSE 2 and/or Artistic 1 or each later version.
+
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
